InAppFieldPath class
Constructors
-
InAppFieldPath(List<
String> segments) -
factory
- InAppFieldPath.fromString(String path)
-
factory
Properties
- field → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isDocumentId → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
segments
→ List<
String> -
final
- type → InAppFieldPaths
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- documentId → const InAppFieldPath